BufferAttribute<TData extends NativeArray<num>> class abstract

Inheritance
Implementers

Constructors

BufferAttribute(TData arrayList, int itemSize, [bool normalized = false])

Properties

array ↔ TData
getter/setter pairinherited
buffer ↔ int?
getter/setter pairinherited
count ↔ int
getter/setter pairinherited
data ↔ InterleavedBuffer?
getter/setter pairinherited
elementSize ↔ int?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
isBufferAttribute ↔ bool
getter/setter pair
itemSize ↔ int
getter/setter pairinherited
length → int
no setter
name ↔ String?
getter/setter pairinherited
needsUpdate ← bool
no getter
normalized ↔ bool
getter/setter pairinherited
onUploadCallback ↔ void Function()?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pairinherited
updateRange ↔ Map<String, int>?
getter/setter pairinherited
usage ↔ int
getter/setter pairinherited
version ↔ int
getter/setter pairinherited

Methods

applyMatrix3(Matrix3 m) → BufferAttribute<NativeArray<num>>
applyMatrix4(Matrix4 m) → void
applyNormalMatrix(dynamic m) → BufferAttribute<NativeArray<num>>
clone() → BufferAttribute<NativeArray<num>>
copy(BufferAttribute<NativeArray<num>> source) → BufferAttribute<NativeArray<num>>
copyArray(TData array) → BufferAttribute<NativeArray<num>>
copyAt(int index1, BufferAttribute<NativeArray<num>> attribute, int index2) → BufferAttribute<NativeArray<num>>
copyColorsArray(List<Color> colors) → BufferAttribute<NativeArray<num>>
copyVector2sArray(List<Vector2> vectors) → BufferAttribute<NativeArray<num>>
copyVector3sArray(List<Vector3> vectors) → BufferAttribute<NativeArray<num>>
copyVector4sArray(List<Vector4> vectors) → BufferAttribute<NativeArray<num>>
getAt(int index) → num?
getW(int index) → num?
getX(int index) → num?
getY(int index) → num?
getZ(int index) → num?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onUpload(void callback()?) → BufferAttribute<NativeArray<num>>
set(dynamic value, {int offset = 0}) → BufferAttribute<NativeArray<num>>
setUsage(int value) → BufferAttribute<NativeArray<num>>
setW(int index, dynamic w) → BufferAttribute<NativeArray<num>>
setX(int index, dynamic x) → BufferAttribute<NativeArray<num>>
setXY(int index, dynamic x, dynamic y) → BufferAttribute<NativeArray<num>>
setXYZ(int index, num x, num y, num z) → void
setXYZW(int index, dynamic x, dynamic y, dynamic z, dynamic w) → BufferAttribute<NativeArray<num>>
setY(int index, dynamic y) → BufferAttribute<NativeArray<num>>
setZ(int index, dynamic z) → BufferAttribute<NativeArray<num>>
toJSON([dynamic data]) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
transformDirection(Matrix4 m) → BufferAttribute<NativeArray<num>>

Operators

operator ==(Object other) → bool
The equality operator.
inherited