Object3D class

Mixed-in types
Implementers

Constructors

Object3D()
Object3D.fromJSON(Map<String, dynamic> json, Map<String, dynamic> rootJSON)

Properties

autoUpdate ↔ bool
getter/setter pair
background ↔ dynamic
getter/setter pair
bindMatrix ↔ Matrix4?
getter/setter pair
castShadow ↔ bool
getter/setter pair
children ↔ List<Object3D>
getter/setter pair
count ↔ int?
getter/setter pair
customDepthMaterial ↔ Material?
Custom depth material to be used when rendering to the depth map. Can only be used in context of meshes. When shadow-casting with a DirectionalLight or SpotLight, if you are (a) modifying vertex positions in the vertex shader, (b) using a displacement map, (c) using an alpha map with alphaTest, or (d) using a transparent texture with alphaTest, you must specify a customDepthMaterial for proper shadows.
getter/setter pair
customDistanceMaterial ↔ Material?
getter/setter pair
environment ↔ Texture?
getter/setter pair
extra ↔ Map<String, dynamic>
getter/setter pair
frustumCulled ↔ bool
getter/setter pair
geometry ↔ BufferGeometry?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
getter/setter pair
instanceColor ↔ BufferAttribute<NativeArray<num>>?
getter/setter pair
instanceMatrix ↔ InstancedBufferAttribute?
getter/setter pair
isImmediateRenderObject ↔ bool
getter/setter pair
layers ↔ Layers
getter/setter pair
material ↔ dynamic
getter/setter pair
matrix ↔ Matrix4
getter/setter pair
matrixAutoUpdate ↔ bool
getter/setter pair
matrixWorld ↔ Matrix4
getter/setter pair
matrixWorldNeedsUpdate ↔ bool
getter/setter pair
modelViewMatrix ↔ Matrix4
getter/setter pair
morphTargetDictionary ↔ Map<String, dynamic>?
getter/setter pair
morphTargetInfluences ↔ List<num>?
getter/setter pair
name ↔ String
getter/setter pair
normalMatrix ↔ Matrix3
getter/setter pair
onBeforeRender ↔ Function?
getter/setter pair
overrideMaterial ↔ Material?
getter/setter pair
parent ↔ Object3D?
getter/setter pair
position ↔ Vector3
getter/setter pair
quaternion ↔ Quaternion
getter/setter pair
receiveShadow ↔ bool
getter/setter pair
renderOrder ↔ int
getter/setter pair
rotation ↔ Euler
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale ↔ Vector3
getter/setter pair
skeleton ↔ Skeleton?
getter/setter pair
tag ↔ String?
getter/setter pair
type ↔ String
getter/setter pair
up ↔ Vector3
getter/setter pair
userData ↔ Map<String, dynamic>
getter/setter pair
uuid ↔ String
getter/setter pair
visible ↔ bool
getter/setter pair

Methods

add(Object3D object) → Object3D
addAll(List<Object3D> objects) → Object3D
addEventListener(String type, Function listener) → void
inherited
applyMatrix4(Matrix4 matrix) → void
applyQuaternion(Quaternion q) → Object3D
attach(Object3D object) → Object3D
clear() → Object3D
clearListeners() → void
inherited
clone([bool? recursive]) → Object3D
copy(Object3D source, [bool? recursive = true]) → Object3D
dispatchEvent(Event event) → void
inherited
dispose() → void
extractFromCache(Map<String, dynamic> cache) → List<Map<String, dynamic>>
getObjectById(String id) → Object3D?
getObjectByName(String name) → Object3D?
getObjectByProperty(String name, String value) → Object3D?
getProperty(String propertyName) → dynamic
getValue(String name) → Matrix4?
getWorldDirection(Vector3 target) → Vector3
getWorldPosition(Vector3? target) → Vector3
getWorldQuaternion(Quaternion target) → Quaternion
getWorldScale(Vector3 target) → Vector3
hasEventListener(String type, Function listener) → bool
inherited
init() → void
localToWorld(dynamic vector) → dynamic
lookAt(Vector3 position) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAfterRender({WebGLRenderer? renderer, dynamic scene, Camera? camera, dynamic geometry, dynamic material, dynamic group}) → void
onQuaternionChange() → void
onRotationChange() → void
raycast(Raycaster raycaster, List<Intersection> intersects) → void
remove(Object3D object) → Object3D
removeEventListener(String type, Function listener) → void
inherited
removeFromParent() → Object3D
removeList(List<Object3D> objects) → Object3D
rotateOnAxis(dynamic axis, num angle) → Object3D
rotateOnWorldAxis(dynamic axis, num angle) → Object3D
rotateX(num angle) → Object3D
rotateY(num angle) → Object3D
rotateZ(num angle) → Object3D
serialize(Map<String, dynamic> library, dynamic element, Object3dMeta? meta) → dynamic
setProperty(String propertyName, dynamic value) → void
setRotationFromAxisAngle(dynamic axis, num angle) → void
setRotationFromEuler(Euler euler) → void
setRotationFromMatrix(dynamic m) → void
setRotationFromQuaternion(Quaternion q) → void
toJSON({Object3dMeta? meta}) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
translateOnAxis(dynamic axis, num distance) → Object3D
translateX(dynamic distance) → Object3D
translateY(dynamic distance) → Object3D
translateZ(dynamic distance) → Object3D
traverse(dynamic callback) → void
traverseAncestors(dynamic callback) → void
traverseVisible(dynamic callback) → void
updateMatrix() → void
updateMatrixWorld([bool force = false]) → void
updateWorldMatrix(bool updateParents, bool updateChildren) → void
worldToLocal(dynamic vector) → dynamic

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defaultMatrixAutoUpdate ↔ bool
getter/setter pair
defaultUp ↔ Vector3
getter/setter pair

Static Methods

castJSON(Map<String, dynamic> json, Map<String, dynamic> rootJSON) → EventDispatcher