three3d/objects/mesh library

Classes

Mesh

Functions

checkBufferGeometryIntersection(Object3D object, Material material, Raycaster raycaster, Ray ray, BufferAttribute<NativeArray<num>> position, dynamic morphPosition, dynamic morphTargetsRelative, dynamic uv, dynamic uv2, int a, int b, int c) → Intersection?
checkIntersection(Object3D object, Material material, Raycaster raycaster, Ray ray, Vector3 pA, Vector3 pB, Vector3 pC, Vector3 point) → Intersection?